<?php defined( 'ABSPATH' ) || exit;

class The_Gift_Wrapper_Admin_Notices {

	private static $outdated_files = array();

	/**
	 * Constructor
	 */
	 public function __construct() {

		// Help cure open source burnout!
		add_action( 'admin_notices', array( $this, 'help_a_girl_out_notice' ) );

		// Alert for folks who haven't set up a wrap category
		add_action( 'admin_notices', array( $this, 'setup_error_notice' ) );

		// Ajax dismiss "help a girl out" notice
		add_action( 'wp_ajax_wcgwp_dismiss_notice', array( $this, 'dismiss_notice' ) );

		// Alert for folks with outdated template files
		add_action( 'admin_notices', array( $this, 'template_file_check_notice' ) );

	}

	/**
	 * Maybe bother users with important information
	 *
	 * @return void
	 */
	 public function help_a_girl_out_notice() {

		$screen = get_current_screen();
		$screen_id = $screen ? $screen->id : '';
		if ( 'woocommerce_page_wc-settings' !== $screen_id && 'woocommerce_page_wc-status' !== $screen_id ) {
			return;
		}

		if ( defined( 'DISABLE_NAG_NOTICES' ) && 'true' === 'DISABLE_NAG_NOTICES' ){
			return;
		}
		// admin.php?page=wc-settings&tab=gift-wrapper&section=order_wrapping

		if ( ( isset( $_GET['section'] ) && '' === $_GET['section'] ) && empty( get_option( 'wcgwp_donate_dismiss_11-29' ) ) ) { ?>
			<div class="updated settings-error notice is-dismissible wcgwp-donation">
				<p style="font-size: 1.15em;">
					If you find <strong>WooCommerce Gift Wrapper</strong> useful, and particularly if you benefit from it, consider upgrading to the much more powerful <a href="https://www.giftwrapper.app" target="_blank" rel="noopener">Gift Wrapper Plus from Sagehen Studio</a>. If that's not in your budget I understand. Please take a moment to write <a href="https://wordpress.org/support/plugin/woocommerce-gift-wrapper/reviews/?filter=5" target="_blank" rel="noopener">an encouraging review</a>, or donate a couple dollars (like $2) using the PayPal link below. Your enthusiasm makes donating my time to this open-source project worthwhile!
				</p>
				<p style="font-size: 1.15em;">
					Refer to the <a href="https://wordpress.org/plugins/woocommerce-gift-wrapper/#faq-header" target=_blank" rel="noopener">FAQ</a> and <a href="https://wordpress.org/support/plugin/woocommerce-gift-wrapper/" target="_blank" rel="noopener nofollow">support forum</a> where your question might already be answered, and if a feature is missing, upgrade to the paid version <em>and you'll likely get it</em>. I provide thorough email support to my paying customers (thank you 😘).
				</p>
				<!--<p style="font-size: 1.15em;">
					If you have questions about the free version of WooCommerce Gift Wrapper which aren't already answered in the wordpress.org/support/plugin/woocommerce-gift-wrapper forum, please <a href="https://wordpress.org/support/plugin/woocommerce-gift-wrapper/" target="_blank" rel="noopener nofollow">open a new topic</a>. I respond to inquiries about the free version of Gift Wrapper as a volunteer in my spare time. Please <a href="https://www.wpbeginner.com/beginners-guide/how-to-properly-ask-for-wordpress-support-and-get-it/" target="_blank" rel="noopener noreferrer">follow these guidelines for the quickest help</a>.
				</p>-->
				<p style="font-size: 1.25em;text-align:center">
					PayPal: <a href="https://www.paypal.com/paypalme/SageHenStudio" target="_blank" rel="noopener noreferrer">paypal.me/SagehenStudio</a>
				</p>
				<button style="z-index: 100;" data-security="<?php echo esc_attr( wp_create_nonce('wcgwp-donate-11-29') ); ?>" type="button" class="notice-dismiss wcgwp-donation-dismiss">
					<span class="screen-reader-text">Dismiss this notice.</span>
				</button>
			</div>
			<?php wp_enqueue_script( 'wcgiftwrap-admin-js' );
		}

	}

	/**
	 * AJAX-called function to delete nag
	 *
	 * @return void
	 */
	 public function dismiss_notice() {

		check_admin_referer( 'wcgwp-donate-11-29', 'security' );
		// Newest at top
		delete_option( 'wcgwp_donate_dismiss_12-14' );
		delete_option( 'wcgwp_donate_dismiss_10-14' );
		delete_option( 'wcgwp_donate_dismiss_11-16' );
		delete_option( 'wcgwp_donate_dismiss_03-21' );
		delete_option( 'wcgwp_donate_dismiss_02-04' );
		delete_option( 'wcgwp_donate_dismiss_05-24' );
		delete_option( 'wcgwp_donate_dismiss_08-24' );
		delete_option( 'wcgwp_donate_dismiss_09-08' );
		update_option( 'wcgwp_donate_dismiss_11-29', true, false );
		wp_die();

	}

	/**
	 * Provide user with heads up if gift wrap category is not set
	 *
	 * @return void
	 */
	 public function setup_error_notice() {

		$screen = get_current_screen();
		if ( $screen->id !== 'woocommerce_page_wc-settings' && $screen->id !== 'woocommerce_page_wc-status'  ) {
			return;
		}

		$wrap_cat_id = get_option( 'wcgwp_category_id' );
		$wrap_cat_id = apply_filters( 'wpml_object_id', $wrap_cat_id, 'product_cat', true );
		$display = (array) get_option( 'wcgwp_display', array() );

		// Admin doesn't have a gift wrap category set!
		if ( 'none' === $wrap_cat_id && ! in_array( 'none', $display ) ) { ?>
				<div id="message" class="notice notice-error is-dismissible">
					<p><?php wp_kses_post( sprintf( __( 'Gift Wrapper is not set up properly. Please choose a category to represent your gift wrap options <a href="%s">in the settings</a>.', 'woocommerce-gift-wrapper' ), admin_url( 'admin.php?page=wc-settings&tab=gift-wrapper' ) ) ); ?></p>
				</div>
		<?php }

	}

	/**
	 * If WC admin page, send core templates to check_template_outdated() method
	 * for version-checking
	 *
	 * @return void
	 */
	public static function template_file_check_notice() {

		$screen = get_current_screen();
		if ( $screen->id !== 'woocommerce_page_wc-settings' && $screen->id !== 'woocommerce_page_wc-status' ) {
			return;
		}
		$core_templates = WC_Admin_Status::scan_template_files( GIFTWRAPPER_PLUGIN_DIR . '/templates' );
		$outdated = self::check_template_outdated( $core_templates );
		if ( $outdated ) {
			gift_wrapper_outdated_template_notice( self::$outdated_files );
		}

	}

	/**
	 * Compare plugin template files with any user overrides,
	 * looking for outdated versions in order to warn user
	 *
	 * @param  array $files
	 * @return boolean
	 */
	public static function check_template_outdated( $files ) {

		if ( empty( $files ) ) {
			return false;
		}
		$theme_file = false;
		$outdated   = false;
		foreach ( $files as $file ) {

			if ( file_exists( get_stylesheet_directory() . '/' . WC()->template_path() . $file ) ) {
				$theme_file = get_stylesheet_directory() . '/' . WC()->template_path() . $file;
			} elseif ( file_exists( get_template_directory() . '/' . WC()->template_path() . $file ) ) {
				$theme_file = get_template_directory() . '/' . WC()->template_path() . $file;
			}

			if ( false !== $theme_file ) {
				$core_version  = WC_Admin_Status::get_file_version( GIFTWRAPPER_PLUGIN_DIR . '/templates/' . $file );
				$theme_version = WC_Admin_Status::get_file_version( $theme_file );

				if ( $core_version && $theme_version && version_compare( $theme_version, $core_version, '<' ) ) {
					$outdated = true;
					if ( ! in_array( $theme_file, self::$outdated_files ) ) {
						self::$outdated_files[] = $theme_file;
					}
				}
			}

		}
		return $outdated;

	}

}

/**
 * Provide user with heads up if template has been updated
 *
 * @param array $outdated_files
 * @return void
 */
function gift_wrapper_outdated_template_notice( $outdated_files ) {

	if ( defined( 'DISABLE_NAG_NOTICES' ) && 'DISABLE_NAG_NOTICES' == true ) {
		return;
	}

	$theme = wp_get_theme();
	?>
	<div id="message" class="updated woocommerce-message notice notice-error is-dismissible">
		<p>
			<?php /* translators: %s: theme name */ ?>
			<strong><?php printf( wp_kses( __( 'Your theme (%s) contains outdated copies of some WooCommerce Gift Wrapper template files.' , 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ), esc_html( $theme['Name'] ) ) ); ?></strong><br />
			<?php esc_html_e( 'The following files should be updated to reflect parent template file changes to ensure they are secure and compatible with the current version of Gift Wrapper.', 'woocommerce-gift-wrapper' ); ?>  
			<ol>
			<?php foreach ( $outdated_files as $file ) { ?>
				<li><?php echo esc_html( $file ); ?></li>
			<?php } ?>
			</ol>
			<?php esc_html_e( 'If you copied over a template file to your theme to change something, you will need to copy the new version of the template and apply your changes again.', 'woocommerce-gift-wrapper' ); ?>
		</p>

	</div>

<?php }