<?php defined( 'ABSPATH' ) || exit;

	class The_Gift_Wrapper_Settings_Product {

		/**
		 * Constructor
		 */
		public function __construct() {

			if ( ! is_admin() ) {
				return;
			}

			// Add settings to WooCommerce simple product
			add_filter( 'woocommerce_product_data_tabs', array( $this, 'product_write_panel_tab' ) );

			// Add the panel and items to the product interface
			add_action( 'woocommerce_product_data_panels', array( $this, 'product_data_panel' ) );

			// Set select as disabled
			add_filter( 'wp_dropdown_cats', array( $this, 'dropdown_cats' ), 10, 2 );

		}

		/**
		 * Adds a new tab to the product interface
		 *
		 * @param  array $tabs
		 * @return array
		 */
		public function product_write_panel_tab( $tabs ) {

			if ( isset( $tabs['gift-wrapper'] ) ) {
				return $tabs;
			}

			global $post;
			if ( ! is_object( $post ) ) {
				return $tabs;
			}
			$post_id = $post->ID;

			// Exit if we are on Gift Wrap product page
			if ( WC_Gift_Wrap()->wrapping->is_wrap( $post_id ) ) {
				return $tabs;
			}
			?>

			<style>#woocommerce-product-data ul.wc-tabs li.gift-wrapper-tab a::before{content:"\f328"}</style>

			<?php
			$tabs['gift-wrapper'] = array(
				'label'  => __( 'Gift Wrapper', 'woocommerce-gift-wrapper' ),
				'target' => 'gift-wrapper-product-options',
				'class'  => array( 'gift-wrapper-tab' ),
			);
			return $tabs;

		}

		/**
		 * Product category arguments, used in settings
		 *
		 * @param  object     $product
		 * @param  boolean    $variable_product
		 * @param  string|int $loop
		 * @return array
		 */
		public function category_args( $product, $variable_product = false, $loop = '' ) {

			$name = '_wcgwp_category';
			$id = '_wcgwp_category';
			if ( true === $variable_product ) {
				$name = '_wcgwp_category_var[' . $loop . ']';
				$id = '_wcgwp_category' . $loop;
			}

			// WPML
			$product_id = apply_filters( 'wpml_object_id',  $product->ID, 'product', true );

			$args = array(
				'taxonomy'          => 'product_cat',
				'show_option_none'  => __( 'Use global settings', 'woocommerce-gift-wrapper' ),
				'orderby'           => 'name',
				'order'             => 'DESC',
				'hierarchical'      => true,
				'name'              => $name,
				'id'                => $id,
				'class'             => 'select short',
				'selected'          => get_post_meta( $product_id, '_wcgwp_category', true ),
			);
			return apply_filters( 'wcgwp_category_args', $args, $product );

		}

		/**
		 * Filter the dropdown category output to add disabled tag
		 *
		 * @param  string $output      HTML output.
		 * @param  array  $parsed_args Arguments used to build the drop-down.
		 * @return string
		 */
		public function dropdown_cats( $output, $parsed_args ) {

			if ( '_wcgwp_category' === $parsed_args['id'] ) {
				return str_replace( '<select ', '<select disabled ', $output );
			}
			return $output;

		}

		/**
		 * Adds the panel and items to the product interface
		 *
		 * @return void
		 */
		public function product_data_panel() {

			global $post;

			// Exit if we are on Gift Wrap product page
			if ( WC_Gift_Wrap()->wrapping->is_wrap( $post->ID ) ) {
				return;
			}

			// WPML
			$post_id = apply_filters( 'wpml_object_id',  $post->ID, 'product', true );
			?>

				<div id="gift-wrapper-product-options" class="panel woocommerce_options_panel hidden">
					<div class="options_group">
						<div id="wcgwp-plus-only-product"><p><strong>Per-product gift wrap settings are a feature of Gift Wrapper Plus. <a href="https://www.giftwrapper.app" rel="noopener" target="_blank" class="button btn">Get Gift Wrapper Plus</a></strong></p>
						</div>
						<p class="form-field wcgwp-plus">
							<label for="wcgwp_wrap_this"><?php esc_html_e( 'Override global settings', 'woocommerce-gift-wrapper' ); ?></label>
							<select id="wcgwp_wrap_this" name="_wcgwp_wrap_this" class="wcgwp_select select short" disabled>
								<?php $selected = esc_attr( get_post_meta( $post_id, '_wcgwp_wrap_this', true ) ); ?>
								<option value="default" <?php selected( $selected, 'default' ); ?>><?php esc_html_e( 'Use global settings', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="yes" <?php selected( $selected, 'yes' ); ?>><?php esc_html_e( 'Yes, gift wrap this (override)', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="no" <?php selected( $selected, 'no' ); ?>><?php esc_html_e( 'No, do not gift wrap (override)', 'woocommerce-gift-wrapper' ); ?></option>
							</select>
						</p>
						<p class="form-field wcgwp-plus">
							<label for="_wcgwp_category"><?php esc_html_e( 'Gift wrap category to use', 'woocommerce-gift-wrapper' ); ?></label>
							<?php wp_dropdown_categories( $this->category_args( $post ) ); ?>
							<?php echo wc_help_tip( __( 'Define the category which holds your gift wrap product(s). Default is the global gift wrap settings category.', 'woocommerce-gift-wrapper' ) ); ?>
						</p>
						<p class="form-field wcgwp-plus">
							<label for="_wcgwp_product"><?php esc_html_e( 'Gift wrap product to use', 'woocommerce-gift-wrapper' ); ?></label>
							<textarea name="_wcgwp_product_id" id="_wcgwp_product" placeholder="Product IDs, one per line" class="short" rows="2" cols="20" disabled><?php echo esc_html( get_post_meta( $post_id, '_wcgwp_product_id', true ) ); ?></textarea>
							<?php echo wc_help_tip( __( 'Define a specific wrap product for this product, using its product ID. Overrides the category setting above.', 'woocommerce-gift-wrapper' ) ); ?>
						</p>
						<p class="form-field wcgwp-plus">
							<label for="wcgwp_show_thumbs"><?php esc_html_e( 'Show thumbnails?', 'woocommerce-gift-wrapper' ); ?></label>
							<select id="wcgwp_show_thumbs" name="_wcgwp_show_thumbs" class="wcgwp_select select short" disabled>
								<?php $selected = esc_attr( get_post_meta( $post_id, '_wcgwp_show_thumbs', true ) ); ?>
								<option value="default" <?php selected( $selected, 'default' ); ?>><?php esc_html_e( 'Not set', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="yes" <?php selected( $selected, 'yes' ); ?>><?php esc_html_e( 'Yes', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="no" <?php selected( $selected, 'no' ); ?>><?php esc_html_e( 'No', 'woocommerce-gift-wrapper' ); ?></option>
							</select>
							<?php echo wc_help_tip( __( 'Should gift wrap product thumbnail images be visible to customers on product pages?', 'woocommerce-gift-wrapper' ) ); ?>
						</p>
						<p class="form-field wcgwp-plus">
							<label for="wcgwp_quantity"><?php esc_html_e( 'Wrap Quantities', 'woocommerce-gift-wrapper' ); ?></label>
							<select id="wcgwp_quantity" name="_wcgwp_product_quantity" class="wcgwp_select select wcgwp_plus" disabled>
								<?php $selected = esc_attr( get_post_meta( $post_id, '_wcgwp_product_quantity', true ) ); ?>
								<option value="default" <?php selected( $selected, 'default' ); ?>><?php esc_html_e( 'Not set', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="ad-lib" <?php selected( $selected, 'ad-lib' ); ?>><?php esc_html_e( 'Any quantity of wrap', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="one-to-one" <?php selected( $selected, 'one-to-one' ); ?>><?php esc_html_e( 'One-to-one wrap per product', 'woocommerce-gift-wrapper' ); ?></option>
								<option value="only-one" <?php selected( $selected, 'only-one' ); ?>><?php esc_html_e( 'One wrap per product', 'woocommerce-gift-wrapper' ); ?></option>
							</select>
							<?php echo wc_help_tip( __( '(Beta setting) Dictate how many giftwraps can be in cart for each line item product. Loose control, in development.', 'woocommerce-gift-wrapper' ) ); ?>
						</p>
					</div>
				</div>

			<?php

		}

	}